/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base;

import java.io.IOException;
import java.util.Iterator;
import java.util.Set;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.co.mintjams.itruth.security.cert.X509Certificate;
import jp.morpho.webapp.servlet.AbstractFilter;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;

/**
 * スーパー管理者であるかどうか判定する ServletFilter です。
 * スーパー管理者でない場合は、アクセスを拒否します。
 */
public class ValidateSuperAdminFilter
	extends AbstractFilter
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.base");

	/**
	 * ValidateSuperAdminFilter を構築します。
	 */
	public ValidateSuperAdminFilter()
	{
		super();
	}

	/**
	 * <P>
	 * スーパー管理者であるかどうか判定します。
	 * </P>
	 * @param request クライアントがサーブレットに行う要求を含む ServletRequest オブジェクト
	 * @param response サーブレットがクライアントに送信する応答を含む ServletResponse オブジェクト
	 * @param chain フィルタチェーン
	 * @exception IOException フィルタが要求を処理するときに、入出力エラーが検出された場合
	 * @exception ServletException 要求を処理できなかった場合
	 * @see javax.servlet.Filter#doFilter(ServletRequest, ServletResponse, FilterChain)
	 */
	public void doFilter(
		ServletRequest request,
		ServletResponse response,
		FilterChain chain)
		throws IOException, ServletException
	{
		boolean allow = false;
		try
		{
			HttpActionRequest actionRequest = HttpActionRequestFactory.getInstance(getServletContext()).getRequest((HttpServletRequest)request);

			/*
			 * クライアント証明書を取得します。
			 */
			X509Certificate x509 = new X509Certificate(actionRequest.getClientCertificate()[0]);

			/*
			 * スーパー管理者の証明書を取得します。
			 */
			Set saSet = getServletContext().getResourcePaths("/WEB-INF/superadmins/");
			for (Iterator i = saSet.iterator(); i.hasNext(); )
			{
				String path = i.next().toString();
				if (path.endsWith(".cer"))
				{
					X509Certificate x509sa = new X509Certificate(getServletContext().getResourceAsStream(path));
					if (x509sa.equals(x509))
					{
						allow = true;
						break;
					}
				}
			}
		}
		catch (Exception e)
		{
			log.log(Level.WARNING, e.getMessage(), e);
		}

		if (!allow)
		{
			((HttpServletResponse)response).sendError(HttpServletResponse.SC_FORBIDDEN);
			return;
		}

		chain.doFilter(request, response);
	}

}
