/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base;

import java.io.IOException;
import java.security.cert.X509Certificate;
import java.util.Iterator;
import java.util.List;
import java.util.logging.Logger;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.co.mintjams.generation.base.util.KeyTools;
import jp.morpho.util.ConversionList;
import jp.morpho.webapp.servlet.AbstractFilter;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;

/**
 * ユーザの証明書からユーザIDを取り出す ServletFilter です。
 */
public class ValidateUserCertFilter
	extends AbstractFilter
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.base");

	/**
	 * ValidateUserCertFilter を構築します。
	 */
	public ValidateUserCertFilter()
	{
		super();
	}

	/**
	 * <P>
	 * ユーザの証明書を検証します。
	 * </P>
	 * @param request クライアントがサーブレットに行う要求を含む ServletRequest オブジェクト
	 * @param response サーブレットがクライアントに送信する応答を含む ServletResponse オブジェクト
	 * @param chain フィルタチェーン
	 * @exception IOException フィルタが要求を処理するときに、入出力エラーが検出された場合
	 * @exception ServletException 要求を処理できなかった場合
	 * @see javax.servlet.Filter#doFilter(ServletRequest, ServletResponse, FilterChain)
	 */
	public void doFilter(
		ServletRequest request,
		ServletResponse response,
		FilterChain chain)
		throws IOException, ServletException
	{
		try
		{
			String userId = null;
			String email = null;

			HttpActionRequest actionRequest = HttpActionRequestFactory.getInstance(getServletContext()).getRequest((HttpServletRequest)request);
			X509Certificate x509 = actionRequest.getClientCertificate()[0];
			KeyTools keyTools = new KeyTools();
			userId = keyTools.getCommonName(x509.getSubjectX500Principal().getName());

			Iterator iterator = x509.getSubjectAlternativeNames().iterator();
			while(iterator.hasNext())
			{
				ConversionList row = new ConversionList((List)iterator.next());
				if (row.getInt(0) == 1)
				{
					email = row.getString(1);
					break;
				}
			}

			request.setAttribute(Globals.USER_ID_KEY, userId);
			request.setAttribute(Globals.USER_EMAIL_KEY, email);
		}
		catch (Exception e)
		{
		}

		if (request.getAttribute(Globals.USER_ID_KEY) == null ||
			request.getAttribute(Globals.USER_EMAIL_KEY) == null)
		{
			((HttpServletResponse)response).sendError(HttpServletResponse.SC_FORBIDDEN);
			return;
		}

		chain.doFilter(request, response);
	}

}
