/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base.action;

import java.io.IOException;
import java.io.InputStreamReader;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.List;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.util.DbUtils;
import jp.co.mintjams.generation.base.util.UrlUtils;
import jp.co.mintjams.itruth.io.CsvReader;
import jp.co.mintjams.itruth.sql.EntityObject;
import jp.co.mintjams.itruth.sql.HybridPreparedStatement;
import jp.co.mintjams.itruth.sql.ResultSetCache;
import jp.co.mintjams.itruth.sql.SQLExecutor;
import jp.morpho.io.ExpandedInputStream;
import jp.morpho.util.ConversionList;
import jp.morpho.util.ConversionMap;
import jp.morpho.util.PrimitiveHolderList;
import jp.morpho.util.PrimitiveHolderMap;
import jp.morpho.util.StringTokenizer;
import jp.morpho.webapp.servlet.http.HttpActionRequest;

/**
 * セットアップを実行します。
 */
public abstract class BaseSetupHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	public BaseSetupHandler()
	{
		super();
	}

	/**
	 * テーブルを作成します。
	 * @param request 要求オブジェクト
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void createTables(HttpActionRequest request) throws IOException, SQLException
	{
		ExpandedInputStream in = null;
		try
		{
			in = ExpandedInputStream.valueOf(request.getSession().getServletContext().getResourceAsStream("/WEB-INF/sql/create.sql"));
			byte[] bytes = in.readAll();
			String schema = new String(bytes, "UTF-8");
			String[] scripts = new StringTokenizer(schema, ";").getTokens();
			SQLExecutor sqlExec = new SQLExecutor(getConnection());
			for (int i = 0; i < scripts.length; i++)
			{
				String sql = scripts[i].trim();
				if (sql.length() > 0)
				{
					sqlExec.executeUpdate(sql);
				}
			}
		}
		finally
		{
			try
			{
				in.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	/**
	 * ユーザを削除するテーブルデータを挿入します。
	 * @param request 要求オブジェクト
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void insertUserDeletables(HttpActionRequest request) throws IOException, SQLException
	{
		if (!DbUtils.existsTable(getConnection(), "gb_userdeletables"))
		{
			return;
		}

		ExpandedInputStream in = null;
		CsvReader reader = null;
		HybridPreparedStatement stmt = null;
		try
		{
			in = ExpandedInputStream.valueOf(request.getSession().getServletContext().getResourceAsStream("/WEB-INF/sql/userdeletables.csv"));
			reader = new CsvReader(new InputStreamReader(in, "UTF-8"));
			List list = reader.readAll();
			StringBuffer sql = new StringBuffer();
			sql.append("INSERT INTO gb_userdeletables");
			sql.append(" (userdeletables_tablename, userdeletables_columnname, userdeletables_description)");
			sql.append(" VALUES (?, ?, ?)");
			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			for (int i = 0; i < list.size(); i++)
			{
				PrimitiveHolderList row = ConversionList.valueOf((List)list.get(i));
				if (row.size() < 2)
				{
					continue;
				}

				stmt.setParameter(1, row.getString(0).trim(), Types.VARCHAR);
				stmt.setParameter(2, row.getString(1).trim(), Types.VARCHAR);
				String description = null;
				if (row.size() > 2 && row.getString(2).trim().length() > 0)
				{
					description = row.getString(2);
				}
				stmt.setParameter(3, description, Types.VARCHAR);
				stmt.executeUpdate();
			}
		}
		finally
		{
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				reader.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				in.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	/**
	 * Portlet データを挿入します。
	 * @param request 要求オブジェクト
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void insertPortlets(HttpActionRequest request) throws IOException, SQLException
	{
		if (!DbUtils.existsTable(getConnection(), "gb_portlets"))
		{
			return;
		}

		ExpandedInputStream in = null;
		CsvReader reader = null;
		HybridPreparedStatement stmt = null;
		try
		{
			in = ExpandedInputStream.valueOf(request.getSession().getServletContext().getResourceAsStream("/WEB-INF/sql/portlets.csv"));
			reader = new CsvReader(new InputStreamReader(in, "UTF-8"));
			List list = reader.readAll();
			StringBuffer sql = new StringBuffer();
			sql.append("INSERT INTO gb_portlets");
			sql.append(" (portlets_id, portlets_url, portlets_width, portlets_height, portlets_description)");
			sql.append(" VALUES (?, ?, ?, ?, ?)");
			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			for (int i = 0; i < list.size(); i++)
			{
				PrimitiveHolderList row = ConversionList.valueOf((List)list.get(i));
				if (row.size() < 5)
				{
					continue;
				}

				stmt.setParameter(1, row.getString(0).trim(), Types.VARCHAR);
				stmt.setParameter(2, row.getString(1).trim(), Types.VARCHAR);
				stmt.setParameter(3, row.getString(2).trim(), Types.DECIMAL);
				stmt.setParameter(4, row.getString(3).trim(), Types.DECIMAL);
				stmt.setParameter(5, row.getString(4).trim(), Types.VARCHAR);
				stmt.executeUpdate();
			}
		}
		finally
		{
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				reader.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				in.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	/**
	 * メニューデータを挿入します。
	 * @param request 要求オブジェクト
	 * @param name メニューの表示名称
	 * @param path メニューがリンクする URL のパス
	 * @param now date_added に設定する Date
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void insertMenu(HttpActionRequest request, String name, String path, java.util.Date now) throws IOException, SQLException
	{
		if (!DbUtils.existsTable(getConnection(), "gb_menus"))
		{
			return;
		}

		StringBuffer sql = new StringBuffer();
		sql.append("SELECT * FROM gb_menus WHERE menus_url = ?");
		HybridPreparedStatement stmt = null;
		ResultSet rs = null;
		try
		{
			path = UrlUtils.getContextPathPrefix(UrlUtils.getProfileContextPath(request)) + path;
			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, path, Types.VARCHAR);
			rs = stmt.executeQuery();
			ResultSetCache rsc = new ResultSetCache(rs, 0, 0);
			if (rsc.getMaxRows() == 0)
			{
				EntityObject eoMenus = EntityObject.getInstance("gb_menus", getConnection());
				//
				PrimitiveHolderMap menus = new ConversionMap();
				menus.putLong("menus_id", now.getTime());
				menus.putString("menus_name", name);
				menus.putString("menus_url", path);
				menus.putInt("menus_no", 0);
				menus.putInt("menus_display", 1);
				menus.putDate("date_added", now);
				menus.putDate("date_lastmodified", now);
				//
				eoMenus.insert(menus);
			}
		}
		finally
		{
			/*
			 * ResultSet をクローズします。
			 */
			try
			{
				rs.close();
			}
			catch (Exception e)
			{
			}
			/*
			 * Statement をクローズします。
			 */
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	/**
	 * テーブルを削除します。
	 * @param request 要求オブジェクト
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void dropTables(HttpActionRequest request) throws IOException, SQLException
	{
		/*
		 * テーブルを削除します。
		 */
		ExpandedInputStream in = null;
		try
		{
			in = ExpandedInputStream.valueOf(request.getSession().getServletContext().getResourceAsStream("/WEB-INF/sql/drop.sql"));
			byte[] bytes = in.readAll();
			String schema = new String(bytes, "UTF-8");
			String[] scripts = new StringTokenizer(schema, ";").getTokens();
			SQLExecutor sqlExec = new SQLExecutor(getConnection());
			for (int i = 0; i < scripts.length; i++)
			{
				String sql = scripts[i].trim();
				if (sql.length() > 0)
				{
					sqlExec.executeUpdate(sql);
				}
			}
		}
		finally
		{
			try
			{
				in.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	/**
	 * ユーザを削除するテーブルデータを削除します。
	 * @param request 要求オブジェクト
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void deleteUserDeletables(HttpActionRequest request) throws IOException, SQLException
	{
		if (!DbUtils.existsTable(getConnection(), "gb_userdeletables"))
		{
			return;
		}

		ExpandedInputStream in = null;
		CsvReader reader = null;
		try
		{
			in = ExpandedInputStream.valueOf(request.getSession().getServletContext().getResourceAsStream("/WEB-INF/sql/userdeletables.csv"));
			reader = new CsvReader(new InputStreamReader(in, "UTF-8"));
			List list = reader.readAll();
			EntityObject eoUserDeletables = EntityObject.getInstance("gb_userdeletables", getConnection());
			for (int i = 0; i < list.size(); i++)
			{
				PrimitiveHolderList row = ConversionList.valueOf((List)list.get(i));
				if (row.size() < 2)
				{
					continue;
				}

				//
				PrimitiveHolderMap userDeletables = new ConversionMap();
				userDeletables.putString("userdeletables_tablename", row.getString(0).trim());
				userDeletables.putString("userdeletables_columnname", row.getString(1).trim());
				//
				eoUserDeletables.deleteByPrimaryKey(userDeletables);
			}
		}
		finally
		{
			try
			{
				reader.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				in.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	/**
	 * Portlet データを削除します。
	 * @param request 要求オブジェクト
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void deletePortlets(HttpActionRequest request) throws IOException, SQLException
	{
		if (!DbUtils.existsTable(getConnection(), "gb_portlets"))
		{
			return;
		}

		ExpandedInputStream in = null;
		CsvReader reader = null;
		try
		{
			in = ExpandedInputStream.valueOf(request.getSession().getServletContext().getResourceAsStream("/WEB-INF/sql/portlets.csv"));
			reader = new CsvReader(new InputStreamReader(in, "UTF-8"));
			List list = reader.readAll();
			EntityObject eoPortlets = EntityObject.getInstance("gb_portlets", getConnection());
			for (int i = 0; i < list.size(); i++)
			{
				PrimitiveHolderList row = ConversionList.valueOf((List)list.get(i));
				if (row.size() < 5)
				{
					continue;
				}

				//
				PrimitiveHolderMap portlets = new ConversionMap();
				portlets.putString("portlets_id", row.getString(0).trim());
				//
				eoPortlets.deleteByPrimaryKey(portlets);
			}
		}
		finally
		{
			try
			{
				reader.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				in.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	/**
	 * メニューデータを削除します。
	 * @param request 要求オブジェクト
	 * @param name メニューの表示名称
	 * @param path メニューがリンクする URL のパス
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void deleteMenu(HttpActionRequest request, String name, String path) throws IOException, SQLException
	{
		if (!DbUtils.existsTable(getConnection(), "gb_menus"))
		{
			return;
		}

		StringBuffer sql = new StringBuffer();
		sql.append("DELETE FROM gb_menus WHERE menus_url = ?");
		HybridPreparedStatement stmt = null;
		try
		{
			path = UrlUtils.getContextPathPrefix(UrlUtils.getProfileContextPath(request)) + path;
			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, path, Types.VARCHAR);
			stmt.executeUpdate();
		}
		finally
		{
			/*
			 * Statement をクローズします。
			 */
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}
	}

}
