/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base.action;

import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.Reader;
import java.sql.Connection;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.servlet.ServletContext;

import jp.co.mintjams.generation.base.Globals;
import jp.morpho.util.PrimitiveHolderMap;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.action.BaseActionHandler;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * SQL を実行するクラスの基本クラスです。
 * Connection を取得するには、DatabaseConnectionHandler とチェーンを構成します。
 */
public abstract class DatabaseAccessHandler extends BaseActionHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.base");

	/**
	 * HttpActionRequest オブジェクト。
	 * doActionHandler を呼び出したときに設定されます。
	 */
	private HttpActionRequest request = null;

	/**
	 * DatabaseAccessHandler を作成します。
	 */
	public DatabaseAccessHandler()
	{
		super();
	}

	/**
	 * 現在処理する要求で使用可能な Connection を返します。
	 *
	 * @return 現在処理する要求で使用可能な Connection 。有効な Connection がない場合は null
	 */
	protected Connection getConnection()
	{
		return (Connection)request.getAttribute(Globals.CONNECTION_KEY);
	}

	/**
	 * この DatabaseAccessHandler を初期化します。
	 * このメソッドをオーバーライドし、最初に super.doActionHandler(request, response, chain) を呼び出してください。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);
		this.request = request;
	}

	/*
	 * ServletContext から文字列リソースを読み込みます。
	 */
	protected String getResourceAsString(ServletContext sc, String path, String encoding)
	{
		Reader in = null;
		try
		{
			in = new InputStreamReader(sc.getResourceAsStream(path), encoding);
			char[] chars = new char[128];
			StringBuffer buf = new StringBuffer();
			while (true)
			{
				int len = in.read(chars, 0, chars.length);
				if (len == -1)
				{
					break;
				}
				buf.append(chars, 0, len);
			}
			return buf.toString();
		}
		catch (Exception e)
		{
			log.log(Level.WARNING, path, e);
		}
		finally
		{
			try
			{
				in.close();
			}
			catch (Exception e)
			{
			}
		}
		return null;
	}

	/*
	 * 実際のファイルを削除します。
	 */
	protected void deleteRealFile(PrimitiveHolderMap slip) throws IOException
	{
		String fileStoreDir = request.getSession().getServletContext().getInitParameter(Globals.FILESTPRE_DIR_KEY);
		File realPath = new File(fileStoreDir + "/" + slip.getString("slips_slip_number"));
		if (!realPath.delete())
		{
			throw new IOException("ファイルが削除できません: " + realPath.getPath());
		}
	}

}
