/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base.action;

import java.sql.Connection;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.sql.DataSource;

import jp.co.mintjams.generation.base.Globals;
import jp.morpho.webapp.action.ActionHandler;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;
import jp.morpho.webapp.sql.DataSourceFactory;

/**
 * データベースへ接続する ActionHandler です。
 * /profile コンテキストの接続を共有します。
 */
public class DatabaseConnectionHandler implements ActionHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.base");

	/**
	 * DatabaseConnectionHandler を作成します。
	 */
	public DatabaseConnectionHandler()
	{
		super();
	}

	/**
	 * データベースへ接続し、次の ActionHandler を呼び出します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		Connection conn = null;
		try
		{
			/*
			 * DataSourceFactory を作成します。
			 */
			DataSourceFactory dsf = DataSourceFactory.getInstance(request);

			/*
			 * DataSource を取得します。
			 */
			DataSource ds = dsf.getDataSource(Globals.DATASOURCE_NAME);

			/*
			 * Connection を取得します。
			 */
			conn = ds.getConnection();
			conn.setAutoCommit(false);

			/*
			 * Connection を HttpActionRequest の属性に設定します。
			 */
			request.setAttribute(Globals.CONNECTION_KEY, conn);

			/*
			 * 次の ActionHandler を呼び出します。
			 */
			chain.doActionHandler(request, response);
		}
		catch (Exception e)
		{
			if (e instanceof ActionHandlerException)
			{
				throw (ActionHandlerException)e;
			}
			log.log(Level.SEVERE, e.getMessage(), e);
			throw new ActionHandlerException(e);
		}
		finally
		{
			/*
			 * Connection を HttpActionRequest の属性から削除します。
			 */
			request.removeAttribute(Globals.CONNECTION_KEY);

			/*
			 * Connection をクローズします。
			 */
			try
			{
				conn.close();
			}
			catch (Exception e)
			{
			}
		}
	}

}
