/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base.action;

import java.util.Map;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.Globals;
import jp.co.mintjams.itruth.sql.EntityObject;
import jp.morpho.util.ConversionMap;
import jp.morpho.util.PrimitiveHolderMap;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * ユーザ情報を取得します。
 */
public class GetUserAttributeHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.base");

	public GetUserAttributeHandler()
	{
		super();
	}

	/**
	 * ユーザ情報を取得します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);

		try
		{
			/*
			 * users にアクセスする EntityObject を作成します。
			 */
			EntityObject eoUsers = EntityObject.getInstance("gb_users", getConnection());

			/*
			 * 列のマップを作成します。
			 */
			PrimitiveHolderMap pkeys = new ConversionMap();
			pkeys.putString("users_id", (String)request.getAttribute(Globals.USER_ID_KEY));

			/*
			 * データを取得します。
			 */
			Map users = eoUsers.findByPrimaryKey(pkeys);

			if (users != null)
			{
				ConversionMap map = ConversionMap.valueOf(users);

				//スタイルシート番号
				request.setAttribute(Globals.USER_COLOR_KEY, map.getString("users_color"));

				//ニックネーム
				request.setAttribute(Globals.USER_NICKNAME_KEY, map.getString("users_name"));

				//管理者権限
				request.setAttribute(Globals.USER_MANAGEABLE_KEY, map.getString("users_manageable"));
			}
			else
			{
				//スタイルシート番号
				request.setAttribute(Globals.USER_COLOR_KEY, "0");

				//ニックネーム
				request.setAttribute(Globals.USER_NICKNAME_KEY, "ゲスト");

				//管理者権限
				request.setAttribute(Globals.USER_MANAGEABLE_KEY, "0");
			}
		}
		catch (Exception e)
		{
		}

		/*
		 * 次の ActionHandler を呼び出します。
		 */
		chain.doActionHandler(request, response);
	}

}
