/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base.util;

import java.io.Serializable;
import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.ResultSet;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * データベースを操作するユーティリティです。
 */
public class DbUtils implements Serializable
{
	/**
	 * DbUtils を作成します。
	 */
	public DbUtils()
	{
		super();
	}

	/**
	 * <P>
	 * テーブルが存在するかどうか判定します。
	 * </P>
	 * @param conn Connection オブジェクト
	 * @param table テーブル名
	 * @return テーブルが存在する場合は true
	 */
	public static boolean existsTable(Connection conn, String table)
	{
		ResultSet rsColumns = null;
		try
		{
			DatabaseMetaData dbmd = conn.getMetaData();
			String[] tablePatterns = {null, "%", table.toLowerCase()};
			rsColumns = dbmd.getColumns(tablePatterns[0], tablePatterns[1], tablePatterns[2], "%");

			for (int i = 0; rsColumns.next(); i++)
			{
				if (tablePatterns[2].equals(rsColumns.getString(3).toLowerCase()))
				{
					return true;
				}
			}
		}
		catch (Exception e)
		{
			Logger log = Logger.getLogger("jp.co.mintjams.generation.base");
			log.log(Level.FINEST, e.getMessage(), e);
		}
		finally
		{
			try
			{
				rsColumns.close();
			}
			catch (Exception e)
			{
			}
		}

		return false;
	}

}
