/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base.util;

import java.io.Serializable;

import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;

import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;

/**
 * URL を操作するユーティリティです。
 */
public class UrlUtils implements Serializable
{

	/**
	 * UrlUtils を作成します。
	 */
	public UrlUtils()
	{
		super();
	}

	/**
	 * <P>
	 * プロフィールのコンテキストパスを返します。
	 * </P>
	 * @param request 要求オブジェクト
	 */
	public static String getProfileContextPath(HttpServletRequest request)
	{
		ServletContext sc = request.getSession().getServletContext();
		HttpActionRequest actionRequest = HttpActionRequestFactory.getInstance(sc).getRequest(request);

		String path = actionRequest.getContextPath();
		return getContextPathPrefix(path) + "/profile";
	}

	/**
	 * <P>
	 * プロフィールのコンテキストパスを返します。
	 * </P>
	 * @param srcpath コンテキストパスのプレフィックスを取得するパス
	 */
	public static String getContextPathPrefix(String srcpath)
	{
		int i = srcpath.lastIndexOf("/");
		if (i <= 0)
		{
			return "";
		}

		return srcpath.substring(0, i);
	}

}
