/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.base.validator;

import java.util.Hashtable;

import jp.morpho.util.StringTokenizer;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.validator.MultiByteLengthValidator;
import jp.morpho.webapp.validator.ValidationException;

/**
 * 同じ値が登録されているかどうかを、データベースに接続して判定する Validator です。
 * 登録されていない場合はエラーになります。
 */
public class MultiLineDuplicateValidator extends MultiByteLengthValidator
{
	private StringBuffer duplicateValues = new StringBuffer();

	/**
	 * 指定された要求オブジェクトの HTTP パラメータの妥当性を検証します。
	 *
	 * @param request 要求オブジェクト
	 * @throws ValidationException 妥当性を検証するときに問題が検出された場合
	 */
	public void validate(HttpActionRequest request) throws ValidationException
	{
		/*
		 * 判定する値をフォームデータから取得します。
		 */
		String value = getFieldValueAsString(request);

		/*
		 * 検証処理を実行するかどうかを判定します。
		 */
		if (!this.isValidate(value))
		{
			return;
		}

		/*
		 * 必須記入の検証を行います。
		 */
		this.validateRequired(value);

		String[] keys = StringTokenizer.tokenize(value, "\r\n");
		Hashtable map = new Hashtable();
		for (int i = 0; i < keys.length; i++)
		{
			if (keys[i].length() > 0)
			{
				boolean errorFlg = false;

				/*
				 * すでにデータがあった場合はエラーにする
				 */
				if (map.containsKey(keys[i]))
				{
					errorFlg = true;
				}
				else
				{
					int bytes = keys[i].getBytes().length;

					if (this.isMinimumSet())
					{
						if (this.getMinimum() * 2 > bytes)
						{
							errorFlg = true;
						}
					}
					if (this.isMaximumSet())
					{
						if (this.getMaximum() * 2 < bytes)
						{
							errorFlg = true;
						}
					}
				}
				map.put(keys[i], "");

				if (errorFlg)
				{
					if (duplicateValues.length() > 0)
					{
						duplicateValues.append(", ");
					}
					duplicateValues.append(keys[i]);
				}
			}
		}
		if (duplicateValues.length() > 0)
		{
			throw new ValidationException("duplicate value");
		}

	}

	public String getDuplicateValues()
	{
		return duplicateValues.toString();
	}
}
