/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile;

import java.io.IOException;
import java.util.logging.Logger;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;

import jp.morpho.util.StringTokenizer;
import jp.morpho.webapp.servlet.AbstractFilter;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionRequestFactory;

/**
 * 要求された URL をからステータスを解析する ServletFilter です。
 */
public class MyPageFilter
	extends AbstractFilter
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	/**
	 * MyPageFilter を構築します。
	 */
	public MyPageFilter()
	{
		super();
	}

	/**
	 * <P>
	 * 要求された URL をからステータスを解析します。
	 * </P>
	 * @param request クライアントがサーブレットに行う要求を含む ServletRequest オブジェクト
	 * @param response サーブレットがクライアントに送信する応答を含む ServletResponse オブジェクト
	 * @param chain フィルタチェーン
	 * @exception IOException フィルタが要求を処理するときに、入出力エラーが検出された場合
	 * @exception ServletException 要求を処理できなかった場合
	 * @see javax.servlet.Filter#doFilter(ServletRequest, ServletResponse, FilterChain)
	 */
	public void doFilter(
		ServletRequest request,
		ServletResponse response,
		FilterChain chain)
		throws IOException, ServletException
	{
		HttpActionRequest actionRequest = HttpActionRequestFactory.getInstance(getServletContext()).getRequest((HttpServletRequest)request);
		String requestURI = actionRequest.getRequestURI().substring(actionRequest.getContextPath().length());
		int sci = requestURI.indexOf(';');
		if (sci != -1)
		{
			requestURI = requestURI.substring(0, sci);
		}

		/*
		 * URL を解析します。
		 */
		StringTokenizer tokenizer = new StringTokenizer(requestURI, "/");
		String baseId = null;
		String statusId = null;
		for (int i = 0; tokenizer.hasMoreTokens(); i++)
		{
			switch (i)
			{
				case 0:
					baseId = tokenizer.nextToken();
					break;
				case 1:
					statusId = tokenizer.nextToken();
					break;
				default:
					tokenizer.nextToken();
					break;
			}
		}

		/*
		 * 取得できた ID によってステータスを切り替えます。
		 */
		if (actionRequest.getStatus() == null || actionRequest.getStatus().length() == 0)
		{
			if (statusId != null)
			{
				actionRequest.setStatus("profile." + statusId);
			}
		}

		chain.doFilter(request, response);
	}

}
