/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile.action;

import java.sql.SQLException;
import java.util.logging.Level;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.action.DatabaseAccessHandler;
import jp.co.mintjams.itruth.sql.HybridPreparedStatement;
import jp.morpho.util.ConversionMap;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * 管理者権限を削除します。
 */
public class DeleteAdminsHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	public DeleteAdminsHandler()
	{
		super();
	}

	/**
	 * 管理者権限を削除します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);

		/*
		 * フォームデータを取得します。
		 */
		ConversionMap form = getParameterMap();

		String[] keys = null;
		if (form.isArray("users_ids"))
		{
			keys = (String[])form.get("users_ids");
		}
		else
		{
			keys = new String[1];
			keys[0] = form.getString("users_ids");
		}

		StringBuffer sql = new StringBuffer();
		sql.append("UPDATE gb_users SET users_manageable = 0");
		sql.append(" WHERE users_id = ?");

		HybridPreparedStatement stmt = null;
		try
		{
			/*
			 * 選択されたユーザの管理者権限を削除します。
			 */
			try
			{
				stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));

				for (int i = 0; i < keys.length; i++)
				{
					stmt.setVarchar(1, keys[i]);
					stmt.executeUpdate();
				}
			}
			catch (SQLException e)
			{
				throw e;
			}
			finally
			{
				try
				{
					stmt.close();
				}
				catch (Exception e)
				{
				}
			}

			/*
			 * コミットします。
			 */
			getConnection().commit();

			/*
			 * ステータスを更新します。
			 */
			request.setStatus("admin.delete.success");
		}
		catch (Exception e)
		{
			/*
			 * ロールバックします。
			 */
			try
			{
				getConnection().rollback();
			}
			catch (Exception sqle)
			{
			}

			/*
			 * 例外トレースを出力します
			 */
			log.log(Level.WARNING, "例外が発生しました", e);

			/*
			 * ステータスを更新します。
			 */
			request.setStatus("admin.delete.failure");
		}

		/*
		 * 次の ActionHandler を呼び出します。
		 */
		chain.doActionHandler(request, response);
	}

}
