/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile.action;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.Globals;
import jp.co.mintjams.generation.base.action.DatabaseAccessHandler;
import jp.co.mintjams.itruth.sql.EntityObject;
import jp.co.mintjams.itruth.sql.HybridPreparedStatement;
import jp.co.mintjams.itruth.sql.ResultSetCache;
import jp.morpho.util.ConversionMap;
import jp.morpho.util.PrimitiveHolderMap;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * MyPortlet を削除します。
 */
public class DeleteMyPortletHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	public DeleteMyPortletHandler()
	{
		super();
	}

	/**
	 * MyPortlet を削除します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);

		/*
		 * フォームデータを取得します。
		 */
		ConversionMap form = getParameterMap();

		try
		{
			String userId = (String)request.getAttribute(Globals.USER_ID_KEY);

			/*
			 * MyPortlet を削除します。
			 */
			EntityObject eoMyportlets = EntityObject.getInstance("gb_myportlets", getConnection());
			PrimitiveHolderMap myportlets = new ConversionMap();
			myportlets.putString("users_id", userId);
			myportlets.putString("portlets_id", form.getString("portlets_id"));
			eoMyportlets.deleteByPrimaryKey(myportlets);

			HybridPreparedStatement stmt = null;

			/*
			 * 削除した MyPortlet の後ろの colum をデクリメントします。
			 */
			try
			{
				StringBuffer sql = new StringBuffer();
				sql.append("UPDATE gb_myportlets SET myportlets_column = myportlets_column - 1");
				sql.append(" WHERE users_id = ?");
				sql.append(" AND myportlets_row = ?");
				sql.append(" AND myportlets_column > ?");
				stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
				stmt.setParameter(1, userId, Types.VARCHAR);
				stmt.setParameter(2, form.getString("myportlets_row"), Types.DECIMAL);
				stmt.setParameter(3, form.getString("myportlets_column"), Types.DECIMAL);
				stmt.executeUpdate();
			}
			catch (SQLException e)
			{
				throw e;
			}
			finally
			{
				try
				{
					stmt.close();
				}
				catch (Exception e)
				{
				}
			}

			ResultSet rs = null;
			int cnt = 0;
			try
			{
				/*
				 * MyPortlet を検索します。
				 */
				StringBuffer sql = new StringBuffer();
				sql.append("SELECT COUNT(*) AS cnt");
				sql.append(" FROM");
				sql.append(" gb_myportlets");
				sql.append(" WHERE users_id = ?");
				sql.append(" AND myportlets_row = ?");

				stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
				stmt.setParameter(1, userId, Types.VARCHAR);
				stmt.setParameter(2, form.getString("myportlets_row"), Types.DECIMAL);
				rs = stmt.executeQuery();
				ResultSetCache rsc = new ResultSetCache(rs, 0, 0);
				if (rsc.getMaxRows() > 0)
				{
					ConversionMap row = ConversionMap.valueOf((Map)rsc.toList().get(0));
					cnt = row.getInt("cnt");
				}
			}
			catch (SQLException e)
			{
				throw e;
			}
			finally
			{
				try
				{
					rs.close();
				}
				catch (Exception e)
				{
				}
				try
				{
					stmt.close();
				}
				catch (Exception e)
				{
				}
			}

			if (cnt == 0)
			{
				/*
				 * 削除した MyPortlet の後ろの row をデクリメントします。
				 */
				try
				{
					StringBuffer sql = new StringBuffer();
					sql.append("UPDATE gb_myportlets SET myportlets_row = myportlets_row - 1");
					sql.append(" WHERE users_id = ?");
					sql.append(" AND myportlets_row > ?");
					stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
					stmt.setParameter(1, userId, Types.VARCHAR);
					stmt.setParameter(2, form.getString("myportlets_row"), Types.DECIMAL);
					stmt.executeUpdate();
				}
				catch (SQLException e)
				{
					throw e;
				}
				finally
				{
					try
					{
						stmt.close();
					}
					catch (Exception e)
					{
					}
				}
			}

			/*
			 * コミットします。
			 */
			getConnection().commit();
		}
		catch (Exception e)
		{
			log.log(Level.WARNING, "例外が発生しました", e);

			/*
			 * ロールバックします。
			 */
			try
			{
				getConnection().rollback();
			}
			catch (Exception e1)
			{
			}

			throw new ActionHandlerException(e.getMessage());
		}

		/*
		 * 次の ActionHandler を呼び出します。
		 */
		chain.doActionHandler(request, response);
	}

}
