/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile.action;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.action.DatabaseAccessHandler;
import jp.co.mintjams.generation.base.util.DbUtils;
import jp.co.mintjams.itruth.sql.HybridPreparedStatement;
import jp.co.mintjams.itruth.sql.ResultSetCache;
import jp.morpho.util.ConversionMap;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * ユーザを削除します。
 */
public class DeleteUsersHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	public DeleteUsersHandler()
	{
		super();
	}

	/**
	 * ユーザを削除します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);

		/*
		 * 現在日時を取得します。
		 */
		java.util.Date now = new java.util.Date();

		/*
		 * フォームデータを取得します。
		 */
		ConversionMap form = getParameterMap();

		String orgUserId = form.getString("users_ids");
		String newUserId = orgUserId + "*" + now.getTime();

		try
		{
			List userdeletables = null;
			/*
			 * ユーザを削除するテーブルを検索します。
			 */
			{
				StringBuffer sql = new StringBuffer();
				sql.append("SELECT");
				sql.append(" *");
				sql.append(" FROM gb_userdeletables");
				sql.append(" ORDER BY userdeletables_tablename, userdeletables_columnname");

				HybridPreparedStatement stmt = null;
				ResultSet rs = null;
				try
				{
					stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
					rs = stmt.executeQuery();
					ResultSetCache rsc = new ResultSetCache(rs, 0, 0);
					userdeletables = rsc.toList();
				}
				catch (SQLException e)
				{
					throw e;
				}
				finally
				{
					try
					{
						rs.close();
					}
					catch (Exception e)
					{
					}
					try
					{
						stmt.close();
					}
					catch (Exception e)
					{
					}
				}
			}

			/*
			 * 選択されたユーザの削除日付を設定します。
			 */
			{
				StringBuffer sql = new StringBuffer();
				sql.append("UPDATE gb_users");
				sql.append(" SET date_deleted = ?");
				sql.append(" WHERE users_id = ?");

				HybridPreparedStatement stmt = null;
				try
				{
					stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
					stmt.setTimestamp(1, now);
					stmt.setVarchar(2, orgUserId);
					stmt.executeUpdate();
				}
				catch (SQLException e)
				{
					throw e;
				}
				finally
				{
					try
					{
						stmt.close();
					}
					catch (Exception e)
					{
					}
				}
			}

			/*
			 * 選択されたユーザを削除します。
			 */
			{
				for (int i = 0; userdeletables != null && i < userdeletables.size(); i++)
				{
					ConversionMap map = ConversionMap.valueOf((Map)userdeletables.get(i));

					if (!DbUtils.existsTable(getConnection(), map.getString("userdeletables_tablename")))
					{
						continue;
					}

					StringBuffer sql = new StringBuffer();
					sql.append("UPDATE ").append(map.getString("userdeletables_tablename"));
					sql.append(" SET ").append(map.getString("userdeletables_columnname")).append(" = ?");
					sql.append(" WHERE ").append(map.getString("userdeletables_columnname")).append(" = ?");

					HybridPreparedStatement stmt = null;
					try
					{
						stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
						if (map.getString("userdeletables_tablename").equals("gb_users") || map.getString("userdeletables_tablename").equals("gb_avatars"))
						{
							stmt.setVarchar(1, newUserId + "*");
						}
						else
						{
							stmt.setVarchar(1, newUserId);
						}
						stmt.setVarchar(2, orgUserId);
						stmt.executeUpdate();
					}
					catch (SQLException e)
					{
						throw e;
					}
					finally
					{
						try
						{
							stmt.close();
						}
						catch (Exception e)
						{
						}
					}
				}
			}

			/*
			 * コミットします。
			 */
			getConnection().commit();

			/*
			 * ステータスを更新します。
			 */
			request.setStatus("user.delete.success");
		}
		catch (Exception e)
		{
			/*
			 * ロールバックします。
			 */
			try
			{
				getConnection().rollback();
			}
			catch (Exception sqle)
			{
			}

			/*
			 * 例外トレースを出力します
			 */
			log.log(Level.WARNING, "例外が発生しました", e);

			/*
			 * ステータスを更新します。
			 */
			request.setStatus("user.delete.failure");
		}

		/*
		 * 次の ActionHandler を呼び出します。
		 */
		chain.doActionHandler(request, response);
	}

}
