/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile.action;

import java.io.FileInputStream;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.Globals;
import jp.co.mintjams.generation.base.action.DatabaseAccessHandler;
import jp.co.mintjams.itruth.sql.EntityObject;
import jp.morpho.io.UploadFile;
import jp.morpho.util.ConversionMap;
import jp.morpho.util.PrimitiveHolderMap;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * ユーザ情報を登録します。
 */
public class EntryUserHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	public EntryUserHandler()
	{
		super();
	}

	/**
	 * ユーザ情報を登録します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);

		/*
		 * 現在日時を取得します。
		 */
		java.util.Date now = new java.util.Date();

		/*
		 * フォームデータを取得します。
		 */
		PrimitiveHolderMap form = getParameterMap();

		try
		{
			String userId = (String)request.getAttribute(Globals.USER_ID_KEY);

			/*
			 * アップロードされたファイルを取得します。
			 */
			UploadFile upload = (UploadFile)form.get("avatars_file");
			String path = (upload != null) ? upload.getUploadPath() : null;
			boolean uploaded = (path != null && path.length() > 0) ? true : false;

			/*
			 * users にアクセスする EntityObject を作成します。
			 */
			EntityObject eoUsers = EntityObject.getInstance("gb_users", getConnection());

			/*
			 * 列のマップを作成します。
			 */
			PrimitiveHolderMap pkeys = new ConversionMap();
			pkeys.putString("users_id", userId);

			/*
			 * データを取得します。
			 */
			Map orgUsers = eoUsers.findByPrimaryKey(pkeys);

			if (orgUsers == null)
			{
				int avatar = (uploaded) ? 1 : 0;
				/*
				 * users にデータを登録します。
				 */
				//
				PrimitiveHolderMap users = new ConversionMap();
				users.putString("users_id", userId);
				users.putString("users_name", form.getString("users_name"));
				users.putString("users_color", form.getString("users_color"));
				users.putInt("users_avatar", avatar);
				users.putDate("date_added", now);
				users.putDate("date_lastmodified", now);
				//
				eoUsers.insert(users);
			}
			else
			{
				int avatar = (uploaded) ? 1 : ConversionMap.valueOf(orgUsers).getInt("users_avatar");

				/*
				 * users データを更新します。
				 */
				//
				PrimitiveHolderMap users = new ConversionMap();
				users.putString("users_id", userId);
				users.putString("users_name", form.getString("users_name"));
				users.putString("users_color", form.getString("users_color"));
				users.putInt("users_avatar", avatar);
				users.putDate("date_lastmodified", now);
				//
				eoUsers.updateByPrimaryKey(users);
			}


			if (uploaded)
			{
				/*
				 * ファイル名を作成します。
				 */
				String fileName = null;
				{
					if (path.indexOf("\\") != -1)
					{
						fileName = path.substring(path.lastIndexOf("\\") + 1);
					}
					else if (path.indexOf("/") != -1)
					{
						fileName = path.substring(path.lastIndexOf("/") + 1);
					}
					else
					{
						fileName = path;
					}
				}

				/*
				 * avatars を削除します。
				 */
				EntityObject eoFiles = EntityObject.getInstance("gb_avatars", getConnection());
				eoFiles.deleteByPrimaryKey(pkeys);

				/*
				 * avatars にデータを登録します。
				 */
				//
				PrimitiveHolderMap files = new ConversionMap();
				files.putString("users_id", userId);
				files.putString("avatars_file_name", fileName);
				files.putString("avatars_file_contenttype", upload.getContentType());
				files.putLong("avatars_file_size", upload.length());
				files.putInputStream("avatars_data", new FileInputStream(upload));
				//
				eoFiles.insert(files);
			}

			/*
			 * コミットします。
			 */
			getConnection().commit();

			/*
			 * ステータスを更新します。
			 */
			request.setStatus("profile.edit.success");
		}
		catch (Exception e)
		{
			/*
			 * 例外トレースを出力します
			 */
			log.log(Level.WARNING, "例外が発生しました", e);

			/*
			 * ロールバックします。
			 */
			try
			{
				getConnection().rollback();
			}
			catch (Exception sqle)
			{
			}

			/*
			 * ステータスを更新します。
			 */
			request.setStatus("profile.edit.failure");
		}

		/*
		 * 次の ActionHandler を呼び出します。
		 */
		chain.doActionHandler(request, response);
	}

}
