/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile.action;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.Globals;
import jp.co.mintjams.generation.base.action.DatabaseAccessHandler;
import jp.co.mintjams.itruth.sql.EntityObject;
import jp.co.mintjams.itruth.sql.HybridPreparedStatement;
import jp.co.mintjams.itruth.sql.ResultSetCache;
import jp.morpho.util.ConversionMap;
import jp.morpho.util.PrimitiveHolderMap;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * MyPortlet の配置を移動します。
 */
public class MoveMyPortletHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	public MoveMyPortletHandler()
	{
		super();
	}

	/**
	 * MyPortlet の配置を移動します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);

		/*
		 * フォームデータを取得します。
		 */
		ConversionMap form = getParameterMap();

		try
		{
			String userId = (String)request.getAttribute(Globals.USER_ID_KEY);
			String portletId = form.getString("portlets_id");
			String type = form.getString("move_type");
			int moveRow = 0;
			int moveCol = 0;
			if (type.equals("left"))
			{
				moveCol = -1;
			}
			else if (type.equals("right"))
			{
				moveCol = 1;
			}
			else if (type.equals("up"))
			{
				moveRow = -1;
			}
			else if (type.equals("down"))
			{
				moveRow = 1;
			}

			int orgRow = form.getInt("myportlets_row");
			int orgCol = form.getInt("myportlets_column");
			int newRow = orgRow + moveRow;
			int newCol = orgCol + moveCol;

			if (orgRow != newRow)
			{
				/*
				 * 上下に移動します。
				 */

				//最大行を取得します。
				int maxRow = getMaxRow(userId);
				if (newRow < 0)
				{
					//移動する MyPortlet の行に他のポートレットがあるか検索します。
					if (getMyPortletColumnsForRow(userId, orgRow) > 1)
					{
						//他のポートレットがあったら

						//一番上に新しい行を追加
						updateMyPortlets(userId, portletId, -1, 0);

						//移動した MyPortlet の後ろの colum をデクリメントします。
						updateColumns(userId, orgRow, orgCol, -1);

						//row をインクリメントします。
						updateRows(userId, -2, 1);
					}
					else
					{
						//他のポートレットがなかったら

						//何もしない
					}
				}
				else if (newRow > maxRow)
				{
					//移動する MyPortlet の行に他のポートレットがあるか検索します。
					if (getMyPortletColumnsForRow(userId, orgRow) > 1)
					{
						//他のポートレットがあったら

						//一番下に新しい行を追加
						updateMyPortlets(userId, portletId, maxRow + 1, 0);

						//移動した MyPortlet の後ろの colum をデクリメントします。
						updateColumns(userId, orgRow, orgCol, -1);
					}
					else
					{
						//他のポートレットがなかったら

						//何もしない
					}
				}
				else
				{
					//移動先の最大列を取得します。
					int maxCol = getMaxCol(userId, newRow);

					//上下の行の最後へ移動
					updateMyPortlets(userId, portletId, newRow, maxCol + 1);

					//移動した MyPortlet の行に他のポートレットがあるか検索します。
					if (getMyPortletColumnsForRow(userId, orgRow) > 0)
					{
						//他のポートレットがあったら

						//移動した MyPortlet の後ろの colum をデクリメントします。
						updateColumns(userId, orgRow, orgCol, -1);
					}
					else
					{
						//他のポートレットがなかったら

						//移動した MyPortlet の後ろの row をデクリメントします。
						updateRows(userId, orgRow, -1);
					}
				}
			}
			else if (orgCol != newCol)
			{
				/*
				 * 左右に移動します。
				 */

				//最大列を取得します。
				int maxCol = getMaxCol(userId, orgRow);
				if (newCol < 0)
				{
					//一番右へ移動
					updateMyPortlets(userId, portletId, orgRow, maxCol + 1);

					//移動した MyPortlet の後ろの colum をデクリメントします。
					updateColumns(userId, orgRow, orgCol, -1);
				}
				else if (newCol > maxCol)
				{
					//一番左へ移動
					updateMyPortlets(userId, portletId, orgRow, -1);

					//移動した MyPortlet の前の colum をインクリメントします。
					updateColumns(userId, orgRow, -2, 1);
				}
				else
				{
					//隣りと交換
					String sidePortletId = getMyPortlet(userId, orgRow, newCol);
					updateMyPortlets(userId, portletId, orgRow, newCol);
					updateMyPortlets(userId, sidePortletId, orgRow, orgCol);
				}
			}
			else
			{
				//移動なし
			}

			/*
			 * コミットします。
			 */
			getConnection().commit();
		}
		catch (Exception e)
		{
			log.log(Level.WARNING, "例外が発生しました", e);

			/*
			 * ロールバックします。
			 */
			try
			{
				getConnection().rollback();
			}
			catch (Exception e1)
			{
			}

			throw new ActionHandlerException(e.getMessage());
		}

		/*
		 * 次の ActionHandler を呼び出します。
		 */
		chain.doActionHandler(request, response);
	}

	private int getMaxRow(String userId) throws Exception
	{
		HybridPreparedStatement stmt = null;
		ResultSet rs = null;
		try
		{
			/*
			 * MyPortlet を検索します。
			 */
			StringBuffer sql = new StringBuffer();
			sql.append("SELECT MAX(myportlets_row) AS cnt");
			sql.append(" FROM");
			sql.append(" gb_myportlets");
			sql.append(" WHERE users_id = ?");

			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, userId, Types.VARCHAR);
			rs = stmt.executeQuery();
			ResultSetCache rsc = new ResultSetCache(rs, 0, 0);

			int cnt = 0;
			if (rsc.getMaxRows() > 0)
			{
				ConversionMap row = ConversionMap.valueOf((Map)rsc.toList().get(0));
				cnt = row.getInt("cnt");
			}
			return cnt;
		}
		catch (SQLException e)
		{
			throw e;
		}
		finally
		{
			try
			{
				rs.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	private int getMaxCol(String userId, int row) throws Exception
	{
		HybridPreparedStatement stmt = null;
		ResultSet rs = null;
		try
		{
			/*
			 * MyPortlet の指定された行の最大列を取得します。
			 */
			StringBuffer sql = new StringBuffer();
			sql.append("SELECT MAX(myportlets_column) AS cnt");
			sql.append(" FROM");
			sql.append(" gb_myportlets");
			sql.append(" WHERE users_id = ?");
			sql.append(" AND myportlets_row = ?");

			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, userId, Types.VARCHAR);
			stmt.setParameter(2, "" + row, Types.DECIMAL);
			rs = stmt.executeQuery();
			ResultSetCache rsc = new ResultSetCache(rs, 0, 0);

			int cnt = 0;
			if (rsc.getMaxRows() > 0)
			{
				ConversionMap rows = ConversionMap.valueOf((Map)rsc.toList().get(0));
				cnt = rows.getInt("cnt");
			}
			return cnt;
		}
		catch (SQLException e)
		{
			throw e;
		}
		finally
		{
			try
			{
				rs.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	private int getMyPortletColumnsForRow(String userId, int row) throws Exception
	{
		HybridPreparedStatement stmt = null;
		ResultSet rs = null;
		int cnt = 0;
		try
		{
			/*
			 * MyPortlet を検索します。
			 */
			StringBuffer sql = new StringBuffer();
			sql.append("SELECT COUNT(*) AS cnt");
			sql.append(" FROM");
			sql.append(" gb_myportlets");
			sql.append(" WHERE users_id = ?");
			sql.append(" AND myportlets_row = ?");

			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, userId, Types.VARCHAR);
			stmt.setParameter(2, "" + row, Types.DECIMAL);
			rs = stmt.executeQuery();
			ResultSetCache rsc = new ResultSetCache(rs, 0, 0);
			if (rsc.getMaxRows() > 0)
			{
				ConversionMap rows = ConversionMap.valueOf((Map)rsc.toList().get(0));
				cnt = rows.getInt("cnt");
			}
			return cnt;
		}
		catch (SQLException e)
		{
			throw e;
		}
		finally
		{
			try
			{
				rs.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	private void updateMyPortlets(String userId, String portletId, int row, int col) throws Exception
	{
		/*
		 * Myportlets を更新します。
		 */
		EntityObject eoMyportlets = EntityObject.getInstance("gb_myportlets", getConnection());
		//
		PrimitiveHolderMap myportlets = new ConversionMap();
		myportlets.putString("users_id", userId);
		myportlets.putString("portlets_id", portletId);
		myportlets.putInt("myportlets_row", row);
		myportlets.putInt("myportlets_column", col);
		//
		eoMyportlets.updateByPrimaryKey(myportlets);
	}

	private void updateColumns(String userId, int row, int col, int param) throws Exception
	{
		HybridPreparedStatement stmt = null;

		/*
		 * 指定された行、列の後ろの colum をデクリメントします。
		 */
		try
		{
			StringBuffer sql = new StringBuffer();
			sql.append("UPDATE gb_myportlets SET myportlets_column = myportlets_column + ?");
			sql.append(" WHERE users_id = ?");
			sql.append(" AND myportlets_row = ?");
			sql.append(" AND myportlets_column > ?");
			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, new Integer(param), Types.VARCHAR);
			stmt.setParameter(2, userId, Types.VARCHAR);
			stmt.setParameter(3, "" + row, Types.DECIMAL);
			stmt.setParameter(4, "" + col, Types.DECIMAL);
			stmt.executeUpdate();
		}
		catch (SQLException e)
		{
			throw e;
		}
		finally
		{
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	private void updateRows(String userId, int row, int param) throws Exception
	{
		HybridPreparedStatement stmt = null;

		/*
		 * 行をインクリメントまたはデクリメントします。
		 */
		try
		{
			StringBuffer sql = new StringBuffer();
			sql.append("UPDATE gb_myportlets SET myportlets_row = myportlets_row + ?");
			sql.append(" WHERE users_id = ?");
			sql.append(" AND myportlets_row > ?");
			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, new Integer(param), Types.DECIMAL);
			stmt.setParameter(2, userId, Types.VARCHAR);
			stmt.setParameter(3, new Integer(row), Types.DECIMAL);
			stmt.executeUpdate();
		}
		catch (SQLException e)
		{
			throw e;
		}
		finally
		{
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}
	}

	private String getMyPortlet(String userId, int row, int col) throws Exception
	{
		HybridPreparedStatement stmt = null;
		ResultSet rs = null;
		try
		{
			/*
			 * MyPortlet を検索します。
			 */
			StringBuffer sql = new StringBuffer();
			sql.append("SELECT portlets_id");
			sql.append(" FROM");
			sql.append(" gb_myportlets");
			sql.append(" WHERE users_id = ?");
			sql.append(" AND myportlets_row = ?");
			sql.append(" AND myportlets_column = ?");

			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, userId, Types.VARCHAR);
			stmt.setParameter(2, "" + row, Types.DECIMAL);
			stmt.setParameter(3, "" + col, Types.DECIMAL);
			rs = stmt.executeQuery();
			ResultSetCache rsc = new ResultSetCache(rs, 0, 0);
			if (rsc.getMaxRows() > 0)
			{
				ConversionMap rows = ConversionMap.valueOf((Map)rsc.toList().get(0));
				return rows.getString("portlets_id");
			}
			throw new Exception("not found myportlet:row=" + row + ", col=" + col);
		}
		catch (SQLException e)
		{
			throw e;
		}
		finally
		{
			try
			{
				rs.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}
	}
}
