/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile.action;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Types;
import java.util.logging.Level;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.Globals;
import jp.co.mintjams.generation.base.action.DatabaseAccessHandler;
import jp.co.mintjams.itruth.sql.HybridPreparedStatement;
import jp.co.mintjams.itruth.sql.ResultSetCache;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * MyPortlet 以外のポートレットを検索します。
 */
public class SearchExceptMyPortletsHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	public SearchExceptMyPortletsHandler()
	{
		super();
	}

	/**
	 * MyPortlet 以外のポートレットを検索します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);

		/*
		 * MyPortlet 以外のポートレットを検索します。
		 */
		StringBuffer sql = new StringBuffer();
		sql.append("SELECT");
		sql.append(" p.portlets_id AS portlets_id");
		sql.append(",p.portlets_url AS portlets_url");
		sql.append(",p.portlets_width AS portlets_width");
		sql.append(",p.portlets_height AS portlets_height");
		sql.append(",p.portlets_description AS portlets_description");
		sql.append(" FROM");
		sql.append(" gb_portlets p");
		sql.append(" LEFT OUTER JOIN (SELECT portlets_id FROM gb_myportlets WHERE users_id = ?) mp ON (p.portlets_id = mp.portlets_id)");
		sql.append(" WHERE mp.portlets_id IS NULL");
		sql.append(" ORDER BY portlets_id");

		HybridPreparedStatement stmt = null;
		ResultSet rs = null;
		try
		{
			stmt = new HybridPreparedStatement(getConnection().prepareStatement(sql.toString()));
			stmt.setParameter(1, (String)request.getAttribute(Globals.USER_ID_KEY), Types.VARCHAR);
			rs = stmt.executeQuery();
			ResultSetCache rsc = new ResultSetCache(rs, 0, 0);

			request.setAttribute("portlets", rsc.toList());
		}
		catch (SQLException e)
		{
			log.log(Level.WARNING, "例外が発生しました", e);
			throw new ActionHandlerException(e.getMessage());
		}
		finally
		{
			try
			{
				rs.close();
			}
			catch (Exception e)
			{
			}
			try
			{
				stmt.close();
			}
			catch (Exception e)
			{
			}
		}

		/*
		 * 次の ActionHandler を呼び出します。
		 */
		chain.doActionHandler(request, response);
	}

}
