/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile.action;

import java.sql.SQLException;
import java.sql.Types;
import java.util.logging.Level;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.action.DatabaseAccessHandler;
import jp.co.mintjams.generation.base.util.Search;
import jp.co.mintjams.itruth.sql.ResultSetCache;
import jp.morpho.util.PrimitiveHolderMap;
import jp.morpho.webapp.action.ActionHandlerChain;
import jp.morpho.webapp.action.ActionHandlerException;
import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * ユーザを検索します。
 */
public class SearchUsersHandler extends DatabaseAccessHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	/**
	 * SearchUsersHandler を作成します。
	 */
	public SearchUsersHandler()
	{
		super();
	}

	/**
	 * ユーザを検索します。
	 *
	 * @see jp.morpho.webapp.action.ActionHandler#doActionHandler(jp.morpho.webapp.servlet.http.HttpActionRequest, jp.morpho.webapp.servlet.http.HttpActionResponse, jp.morpho.webapp.action.ActionHandlerChain)
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException
	{
		super.doActionHandler(request, response, chain);

		/*
		 * フォームデータを取得します。
		 */
		PrimitiveHolderMap form = getParameterMap();

		/*
		 * ページを取得します。
		 */
		int pages = form.getInt("page_no");
		int startNo = 0;
		int endNo = 0;

		if (pages <= 1)
		{
			form.putInt("page_no", 1);
			startNo = 1;
			endNo = form.getInt("max_users_rows");
		}
		else
		{
			startNo = ((pages - 1) * form.getInt("max_users_rows")) + 1;
			endNo = pages * form.getInt("max_users_rows");
		}

		/*
		 * ユーザを検索します。
		 */
		try
		{
			/*
			 * Finder を作成します。
			 */
			Search search = new Search();

			/*
			 * 基本となる SQL を設定します。
			 */
			StringBuffer sql = new StringBuffer();
			sql.append("SELECT");
			sql.append(" *");
			sql.append(" FROM gb_users");
			search.setBaseSQL(sql.toString());

			/*
			 * データベースの列の名前を設定します。
			 */
			search.setColumnName("users_id", "users_id");
			search.setColumnName("users_name", "users_name");
			search.setColumnName("users_manageable", "users_manageable");

			/*
			 * パラメータの SQL 型を設定します。
			 */
			search.setColumnType("users_id", Types.VARCHAR);
			search.setColumnType("users_name", Types.VARCHAR);
			search.setColumnType("users_manageable", Types.DECIMAL);

			/*
			 * 追加の条件を設定します。
			 */
			search.setAppendWhere(" date_deleted IS NULL");

			/*
			 * 検索を実行します。
			 */
			ResultSetCache rsc = search.search(form, getConnection(), startNo, endNo);

			/*
			 * ユーザリストを設定します
			 */
			form.putInt("max_rows", rsc.getMaxRows());
			request.setAttribute("users", rsc.toList());
		}
		catch (SQLException e)
		{
			log.log(Level.WARNING, "例外が発生しました", e);
			throw new ActionHandlerException(e.getMessage());
		}

		/*
		 * 次の ActionHandler を呼び出します。
		 */
		chain.doActionHandler(request, response);
	}

}
