/*
 * MORPHO GENERATION-F, Open Source Groupware Solutions
 * http://www.mintjams.jp/
 *
 * Copyright (c) 2004, MintJams, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the MintJams, Inc. nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.co.mintjams.generation.profile.action;

import java.io.IOException;
import java.sql.SQLException;
import java.util.logging.Logger;

import jp.co.mintjams.generation.base.action.BaseSetupHandler;
import jp.morpho.webapp.servlet.http.HttpActionRequest;

/**
 * セットアップを実行します。
 */
public abstract class SetupHandler extends BaseSetupHandler
{
	Logger log = Logger.getLogger("jp.co.mintjams.generation.profile");

	public SetupHandler()
	{
		super();
	}

	/**
	 * インストールを実行します。
	 * @param request 要求オブジェクト
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void install(HttpActionRequest request) throws IOException, SQLException
	{
		java.util.Date now = new java.util.Date();

		/*
		 * テーブルを作成します。
		 */
		createTables(request);

		/*
		 * ユーザ削除するテーブルデータを挿入します。
		 */
		insertUserDeletables(request);

		/*
		 * Portlet データを挿入します。
		 */
		insertPortlets(request);

		/*
		 * メニューデータを挿入します。
		 */
		insertMenu(request, "HOME", "/profile/mypage/contents", now);
	}

	/**
	 * アンインストールを実行します。
	 * @param request 要求オブジェクト
	 * @exception IOException install.sql が読み込めない場合
	 * @exception SQLException データベースアクセスエラーが発生した場合
	 */
	protected void uninstall(HttpActionRequest request) throws IOException, SQLException
	{
		/*
		 * メニューデータを削除します。
		 */
		deleteMenu(request, "HOME", "/profile/mypage/contents");

		/*
		 * Portlet データを削除します。
		 */
		deletePortlets(request);

		/*
		 * ユーザ削除するテーブルデータを削除します。
		 */
		deleteUserDeletables(request);

		/*
		 * テーブルを削除します。
		 */
		dropTables(request);
	}

}
